[frameworks/kdoctools] /: Rename meinproc5 to meinproc6

Friedrich W. H. Kossebau null at kde.org
Sun May 21 17:02:38 BST 2023


Git commit 8e23c3eedc7f87d02cc0e78228bf709f4a6194e2 by Friedrich W. H. Kossebau.
Committed on 17/05/2023 at 17:17.
Pushed by ltoscano into branch 'master'.

Rename meinproc5 to meinproc6

M  +2    -2    CMakeLists.txt
M  +3    -3    KF6DocToolsConfig.cmake.in
M  +5    -5    KF6DocToolsMacros.cmake
M  +1    -1    autotests/CMakeLists.txt
M  +1    -1    autotests/kdoctools+install/test.cmake
M  +1    -1    docs/CMakeLists.txt
M  +1    -1    docs/checkXML5/man-checkXML5.1.docbook
D  +0    -1    docs/meinproc5/CMakeLists.txt
A  +1    -0    docs/meinproc6/CMakeLists.txt
R  +9    -9    docs/meinproc6/man-meinproc6.1.docbook [from: docs/meinproc5/man-meinproc5.1.docbook - 091% similarity]
M  +9    -9    src/CMakeLists.txt
M  +2    -2    src/checkXML5.cpp

https://invent.kde.org/frameworks/kdoctools/commit/8e23c3eedc7f87d02cc0e78228bf709f4a6194e2

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 1ba2b1f2..f4e4670a 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -86,9 +86,9 @@ remove_definitions(-DQT_NO_CAST_FROM_ASCII)
 set(_kdoctoolsBootStrapping TRUE)
 set(KDOCTOOLS_CUSTOMIZATION_DIR "${CMAKE_CURRENT_BINARY_DIR}/src/customization/")
 if (WIN32)
-    set(KDOCTOOLS_MEINPROC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc5 )
+    set(KDOCTOOLS_MEINPROC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc6 )
 else ()
-    set(KDOCTOOLS_MEINPROC_EXECUTABLE          ${CMAKE_CURRENT_BINARY_DIR}/src/meinproc5${CMAKE_EXECUTABLE_SUFFIX} )
+    set(KDOCTOOLS_MEINPROC_EXECUTABLE          ${CMAKE_CURRENT_BINARY_DIR}/src/meinproc6${CMAKE_EXECUTABLE_SUFFIX} )
 endif ()
 include(KF6DocToolsMacros.cmake)
 
diff --git a/KF6DocToolsConfig.cmake.in b/KF6DocToolsConfig.cmake.in
index ca90ce0d..49a0c62f 100644
--- a/KF6DocToolsConfig.cmake.in
+++ b/KF6DocToolsConfig.cmake.in
@@ -14,9 +14,9 @@ else()
     include("${CMAKE_CURRENT_LIST_DIR}/KF6DocToolsToolsTargets.cmake")
 
     # TODO KF6: deprecated, remove the below
-    if(CMAKE_CROSSCOMPILING AND MEINPROC5_EXECUTABLE)
-        set_target_properties(KF6::meinproc5 PROPERTIES IMPORTED_LOCATION_NONE ${MEINPROC5_EXECUTABLE})
-        set_target_properties(KF6::meinproc5 PROPERTIES IMPORTED_LOCATION ${MEINPROC5_EXECUTABLE})
+    if(CMAKE_CROSSCOMPILING AND MEINPROC6_EXECUTABLE)
+        set_target_properties(KF6::meinproc6 PROPERTIES IMPORTED_LOCATION_NONE ${MEINPROC6_EXECUTABLE})
+        set_target_properties(KF6::meinproc6 PROPERTIES IMPORTED_LOCATION ${MEINPROC6_EXECUTABLE})
     endif()
 
     if(CMAKE_CROSSCOMPILING AND DOCBOOKL10NHELPER_EXECUTABLE)
diff --git a/autotests/CMakeLists.txt b/autotests/CMakeLists.txt
index 33a957ce..cb1e8d05 100644
--- a/autotests/CMakeLists.txt
+++ b/autotests/CMakeLists.txt
@@ -1,6 +1,6 @@
 add_test(
   NAME meinproc_template
-  COMMAND meinproc5 --srcdir ${CMAKE_CURRENT_BINARY_DIR}/../src ${CMAKE_CURRENT_SOURCE_DIR}/../src/template.docbook
+  COMMAND meinproc6 --srcdir ${CMAKE_CURRENT_BINARY_DIR}/../src ${CMAKE_CURRENT_SOURCE_DIR}/../src/template.docbook
   WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}
 )
 
diff --git a/autotests/kdoctools+install/test.cmake b/autotests/kdoctools+install/test.cmake
index 6833a90e..0aadd46d 100644
--- a/autotests/kdoctools+install/test.cmake
+++ b/autotests/kdoctools+install/test.cmake
@@ -4,7 +4,7 @@ set(HTMLPATH ${CMAKE_INSTALL_PREFIX}/${KDE_INSTALL_DOCBUNDLEDIR})
 set(FILES
 # from kdoctools_install
     ${MANPATH}/man1/checkXML5.1
-    ${MANPATH}/man1/meinproc5.1
+    ${MANPATH}/man1/meinproc6.1
     ${MANPATH}/man7/kf5options.7
     ${MANPATH}/man7/qt5options.7
 # from add_subdirectory
diff --git a/docs/CMakeLists.txt b/docs/CMakeLists.txt
index 4efee3b3..26eaae43 100644
--- a/docs/CMakeLists.txt
+++ b/docs/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_subdirectory(checkXML5)
-add_subdirectory(meinproc5)
+add_subdirectory(meinproc6)
 
 add_subdirectory(kf5options)
 add_subdirectory(qt5options)
diff --git a/docs/checkXML5/man-checkXML5.1.docbook b/docs/checkXML5/man-checkXML5.1.docbook
index 7eca7963..c06cd68b 100644
--- a/docs/checkXML5/man-checkXML5.1.docbook
+++ b/docs/checkXML5/man-checkXML5.1.docbook
@@ -40,7 +40,7 @@ documentation.</para>
 
 <refsect1>
 <title>See Also</title>
-<para>meinproc5(1) xmllint(1)</para>
+<para>meinproc6(1) xmllint(1)</para>
 </refsect1>
 </refentry>
 
diff --git a/docs/meinproc5/CMakeLists.txt b/docs/meinproc5/CMakeLists.txt
deleted file mode 100644
index 87692ab7..00000000
--- a/docs/meinproc5/CMakeLists.txt
+++ /dev/null
@@ -1 +0,0 @@
-kdoctools_create_manpage(man-meinproc5.1.docbook 1 INSTALL_DESTINATION ${KDE_INSTALL_MANDIR})
diff --git a/docs/meinproc6/CMakeLists.txt b/docs/meinproc6/CMakeLists.txt
new file mode 100644
index 00000000..ca219d8d
--- /dev/null
+++ b/docs/meinproc6/CMakeLists.txt
@@ -0,0 +1 @@
+kdoctools_create_manpage(man-meinproc6.1.docbook 1 INSTALL_DESTINATION ${KDE_INSTALL_MANDIR})
diff --git a/docs/meinproc5/man-meinproc5.1.docbook b/docs/meinproc6/man-meinproc6.1.docbook
similarity index 91%
rename from docs/meinproc5/man-meinproc5.1.docbook
rename to docs/meinproc6/man-meinproc6.1.docbook
index 968bdc42..e6888a08 100644
--- a/docs/meinproc5/man-meinproc5.1.docbook
+++ b/docs/meinproc6/man-meinproc6.1.docbook
@@ -6,7 +6,7 @@
 <refentry lang="&language;">
 
 <refentryinfo>
-<title>meinproc5 User's Manual</title>
+<title>meinproc6 User's Manual</title>
 <!-- There is no author in the meinproc.cpp file 
 Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man2html?meinproc+1
 
@@ -41,12 +41,12 @@ Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man
 </refentryinfo>
 
 <refmeta>
-<refentrytitle><command>meinproc5</command></refentrytitle>
+<refentrytitle><command>meinproc6</command></refentrytitle>
 <manvolnum>1</manvolnum>
 </refmeta>
 
 <refnamediv>
-<refname><command>meinproc5</command></refname>
+<refname><command>meinproc6</command></refname>
 <refpurpose>&kde; translator for &XML;</refpurpose>
 </refnamediv>
 
@@ -54,7 +54,7 @@ Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man
 <title>Synopsis</title>
 
 <cmdsynopsis>
-<command>meinproc5</command>
+<command>meinproc6</command>
 
 <arg choice="opt">-h, --help</arg>
 <arg choice="opt">-v, --version</arg>
@@ -79,7 +79,7 @@ Also, based on the information from http://olympus.het.brown.edu/cgi-bin/man/man
 <refsect1>
 <title>Description</title>
 
-<para><command>meinproc5</command> converts DocBook files to &HTML;.
+<para><command>meinproc6</command> converts DocBook files to &HTML;.
 </para>
 </refsect1>
 
@@ -128,7 +128,7 @@ Create a cache file for the document.
 <listitem>
 <para>Check the document for validity.</para>
 <screen>The output can be a bit daunting, since one small mistake can cause a cascade of errors. 
-The trick is to look at the first error, fix that error, save the file, and run <command>meinproc5</command> again.
+The trick is to look at the first error, fix that error, save the file, and run <command>meinproc6</command> again.
 </screen>
 </listitem>
 </varlistentry>
@@ -185,9 +185,9 @@ Set parameters to pass to the stylesheet.
 <refsect1>
 <title>Usage</title>
 <para>
-The most common way to run <command>meinproc5</command> is simply as
+The most common way to run <command>meinproc6</command> is simply as
 <literallayout>
-<userinput><command>meinproc5</command> <replaceable>docbook-file</replaceable>
+<userinput><command>meinproc6</command> <replaceable>docbook-file</replaceable>
 </userinput>
 </literallayout>
 where <replaceable>docbook-file</replaceable> is usually index.docbook. 
@@ -197,7 +197,7 @@ Note that these pages are only viewable in &kde;-based browsers (like &konqueror
 <para>
 If you need to view the &HTML; output in another browser (for example, if you're placing it on line), use
 <literallayout>
-<userinput><command>meinproc5</command> --stylesheet <replaceable>stylesheet-name</replaceable> <replaceable>docbook-file</replaceable>
+<userinput><command>meinproc6</command> --stylesheet <replaceable>stylesheet-name</replaceable> <replaceable>docbook-file</replaceable>
 </userinput>
 </literallayout>
 where <replaceable>stylesheet-name</replaceable> is the full path to one of the &XSL;
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 317c4043..2a984f65 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -117,9 +117,9 @@ else ()
     set(meinproc_additional_LIBS KF6::Archive)
 endif()
 
-add_executable(meinproc5 meinproc.cpp meinproc_common.cpp xslt.cpp ${meinproc_additional_SRCS} ${kdoctoolslog_core_SRCS})
-ecm_mark_nongui_executable(meinproc5)
-target_link_libraries(meinproc5
+add_executable(meinproc6 meinproc.cpp meinproc_common.cpp xslt.cpp ${meinproc_additional_SRCS} ${kdoctoolslog_core_SRCS})
+ecm_mark_nongui_executable(meinproc6)
+target_link_libraries(meinproc6
     PRIVATE
         Qt6::Core
         ${LIBXML2_LIBRARIES}
@@ -128,14 +128,14 @@ target_link_libraries(meinproc5
         ${meinproc_additional_LIBS}
 )
 
-target_compile_definitions(meinproc5 PRIVATE -DKDOCTOOLS_EXPORT=)
-install(TARGETS meinproc5 EXPORT KF6DocToolsToolsTargets ${KF_INSTALL_TARGETS_DEFAULT_ARGS})
+target_compile_definitions(meinproc6 PRIVATE -DKDOCTOOLS_EXPORT=)
+install(TARGETS meinproc6 EXPORT KF6DocToolsToolsTargets ${KF_INSTALL_TARGETS_DEFAULT_ARGS})
 
-if(CMAKE_CROSSCOMPILING AND MEINPROC5_EXECUTABLE)
-    add_executable(KF6::meinproc5 IMPORTED GLOBAL)
-    set_target_properties(KF6::meinproc5 PROPERTIES IMPORTED_LOCATION ${MEINPROC5_EXECUTABLE})
+if(CMAKE_CROSSCOMPILING AND MEINPROC6_EXECUTABLE)
+    add_executable(KF6::meinproc6 IMPORTED GLOBAL)
+    set_target_properties(KF6::meinproc6 PROPERTIES IMPORTED_LOCATION ${MEINPROC6_EXECUTABLE})
 else()
-    add_executable(KF6::meinproc5 ALIAS meinproc5)
+    add_executable(KF6::meinproc6 ALIAS meinproc6)
 endif()
 
 ########### customize includes for xslt ###############
diff --git a/src/checkXML5.cpp b/src/checkXML5.cpp
index 7332c200..f321d7e8 100644
--- a/src/checkXML5.cpp
+++ b/src/checkXML5.cpp
@@ -23,9 +23,9 @@ int main(int argc, char **argv)
         return (1);
     }
 
-    const QString exec = QStandardPaths::findExecutable(QStringLiteral("meinproc5"));
+    const QString exec = QStandardPaths::findExecutable(QStringLiteral("meinproc6"));
     if (exec.isEmpty()) {
-        qCCritical(KDocToolsLog) << "Could not find meinproc5 executable in PATH";
+        qCCritical(KDocToolsLog) << "Could not find meinproc6 executable in PATH";
         return 1;
     }
 


More information about the kde-doc-english mailing list
diff --git a/KF6DocToolsMacros.cmake b/KF6DocToolsMacros.cmake
index 1a190a8e..40e10280 100644
--- a/KF6DocToolsMacros.cmake
+++ b/KF6DocToolsMacros.cmake
@@ -5,13 +5,13 @@
 # SPDX-License-Identifier: BSD-3-Clause
 #
 #  KDOCTOOLS_CREATE_HANDBOOK( docbookfile [INSTALL_DESTINATION installdest] [SUBDIR subdir])
 #   Create the handbook from the docbookfile (using meinproc5)
 #   The resulting handbook will be installed to <installdest> when using
 #   INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
 #   SUBDIR <subdir> is specified.
 #
 #  KDOCTOOLS_CREATE_MANPAGE( docbookfile section [INSTALL_DESTINATION installdest])
 #   Create the manpage for the specified section from the docbookfile (using meinproc5)
 #   The resulting manpage will be installed to <installdest> when using
 #   INSTALL_DESTINATION <installdest>.
 #
@@ -49,7 +49,7 @@
 #   If ${KDE_INSTALL_DOCBUNDLEDIR} is not set, share/doc/HTML is used instead.
 #   If ${KDE_INSTALL_MANDIR} is not set, share/man/<lang> is used instead.
 #
-#  KDOCTOOLS_MEINPROC_EXECUTABLE - the meinproc5 executable
+#  KDOCTOOLS_MEINPROC_EXECUTABLE - the meinproc6 executable
 #
 #  KDOCTOOLS_SERIALIZE_TOOL - wrapper to serialize potentially resource-intensive commands during
 #                      parallel builds (set to 'icecc' when using icecream)
@@ -57,11 +57,11 @@
 # The following variables are defined for the various tools required to
 # compile KDE software:
 #
-#  KDOCTOOLS_MEINPROC_EXECUTABLE - the meinproc5 executable
+#  KDOCTOOLS_MEINPROC_EXECUTABLE - the meinproc6 executable
 #
 
 set(KDOCTOOLS_SERIALIZE_TOOL "" CACHE STRING "Tool to serialize resource-intensive commands in parallel builds")
-set(KDOCTOOLS_MEINPROC_EXECUTABLE "KF6::meinproc5")
+set(KDOCTOOLS_MEINPROC_EXECUTABLE "KF6::meinproc6")
 
 if(KDOCTOOLS_SERIALIZE_TOOL)
     # parallel build with many meinproc invocations can consume a huge amount of memory
@@ -5,13 +5,13 @@
 #
 #  KDOCTOOLS_CREATE_HANDBOOK( docbookfile [INSTALL_DESTINATION installdest] [SUBDIR subdir])
-#   Create the handbook from the docbookfile (using meinproc5)
+#   Create the handbook from the docbookfile (using meinproc6)
 #   The resulting handbook will be installed to <installdest> when using
 #   INSTALL_DESTINATION <installdest>, or to <installdest>/<subdir> if
@@ -5,13 +5,13 @@
 #
 #  KDOCTOOLS_CREATE_MANPAGE( docbookfile section [INSTALL_DESTINATION installdest])
-#   Create the manpage for the specified section from the docbookfile (using meinproc5)
+#   Create the manpage for the specified section from the docbookfile (using meinproc6)
 #   The resulting manpage will be installed to <installdest> when using
 #   INSTALL_DESTINATION <installdest>.